summaryrefslogtreecommitdiff
path: root/vpx_dsp/x86/avg_pred_sse2.c
diff options
context:
space:
mode:
authorJohann <johann.koenig@duck.com>2018-10-30 12:59:46 -0700
committerJohann <johann.koenig@duck.com>2018-11-01 12:14:14 -0700
commit96082749aaf639333c0889b3f402291f2eee69b7 (patch)
treedfa32078669b1a441d6485978c076006a2f95b42 /vpx_dsp/x86/avg_pred_sse2.c
parent4635b0fced6df4b371454b52cfd512c14eec1f76 (diff)
downloadlibvpx-96082749aaf639333c0889b3f402291f2eee69b7.tar
libvpx-96082749aaf639333c0889b3f402291f2eee69b7.tar.gz
libvpx-96082749aaf639333c0889b3f402291f2eee69b7.tar.bz2
libvpx-96082749aaf639333c0889b3f402291f2eee69b7.zip
clang-tidy: fix vpx_dsp parameters
BUG=webm:1444 Change-Id: Iee19be068afc6c81396c79218a89c469d2e66207
Diffstat (limited to 'vpx_dsp/x86/avg_pred_sse2.c')
-rw-r--r--vpx_dsp/x86/avg_pred_sse2.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/vpx_dsp/x86/avg_pred_sse2.c b/vpx_dsp/x86/avg_pred_sse2.c
index e7db75559..e4e1e0e7a 100644
--- a/vpx_dsp/x86/avg_pred_sse2.c
+++ b/vpx_dsp/x86/avg_pred_sse2.c
@@ -15,10 +15,10 @@
#include "vpx/vpx_integer.h"
#include "vpx_dsp/x86/mem_sse2.h"
-void vpx_comp_avg_pred_sse2(uint8_t *comp, const uint8_t *pred, int width,
+void vpx_comp_avg_pred_sse2(uint8_t *comp_pred, const uint8_t *pred, int width,
int height, const uint8_t *ref, int ref_stride) {
- /* comp and pred must be 16 byte aligned. */
- assert(((intptr_t)comp & 0xf) == 0);
+ /* comp_pred and pred must be 16 byte aligned. */
+ assert(((intptr_t)comp_pred & 0xf) == 0);
assert(((intptr_t)pred & 0xf) == 0);
if (width > 8) {
int x, y;
@@ -27,17 +27,17 @@ void vpx_comp_avg_pred_sse2(uint8_t *comp, const uint8_t *pred, int width,
const __m128i p = _mm_load_si128((const __m128i *)(pred + x));
const __m128i r = _mm_loadu_si128((const __m128i *)(ref + x));
const __m128i avg = _mm_avg_epu8(p, r);
- _mm_store_si128((__m128i *)(comp + x), avg);
+ _mm_store_si128((__m128i *)(comp_pred + x), avg);
}
- comp += width;
+ comp_pred += width;
pred += width;
ref += ref_stride;
}
} else { // width must be 4 or 8.
int i;
// Process 16 elements at a time. comp and pred have width == stride and
// therefore live in contigious memory. 4*4, 4*8, 8*4, 8*8, and 8*16 are all
// divisible by 16 so just ref needs to be massaged when loading.
for (i = 0; i < width * height; i += 16) {
const __m128i p = _mm_load_si128((const __m128i *)pred);
__m128i r;
@@ -60,10 +60,10 @@ void vpx_comp_avg_pred_sse2(uint8_t *comp, const uint8_t *pred, int width,
ref += 2 * ref_stride;
}
avg = _mm_avg_epu8(p, r);
- _mm_store_si128((__m128i *)comp, avg);
+ _mm_store_si128((__m128i *)comp_pred, avg);
pred += 16;
- comp += 16;
+ comp_pred += 16;
}
}
}
@@ -27,17 +27,17 @@ void vpx_comp_avg_pred_sse2(uint8_t *comp, const uint8_t *pred, int width,
} else { // width must be 4 or 8.
int i;
- // Process 16 elements at a time. comp and pred have width == stride and
- // therefore live in contigious memory. 4*4, 4*8, 8*4, 8*8, and 8*16 are all
- // divisible by 16 so just ref needs to be massaged when loading.
+ // Process 16 elements at a time. comp_pred and pred have width == stride
+ // and therefore live in contigious memory. 4*4, 4*8, 8*4, 8*8, and 8*16 are
+ // all divisible by 16 so just ref needs to be massaged when loading.
for (i = 0; i < width * height; i += 16) {
const __m128i p = _mm_load_si128((const __m128i *)pred);